package os;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.util.logging.Level;
import java.util.logging.LogManager;
import java.util.logging.Logger;

import os.io.StandardInputService;
import os.io.StandardOutputService;
import os.process.InitProcess;
import os.terminal.Terminal;
import os.terminal.TerminalTab;

/**
 * Main class
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 *
 */
public class App
{
    private static Logger logger = Logger.getLogger(App.class.getName());

    public static void main(String[] args) throws InterruptedException {
        Terminal.get().setVisible(true);

        try {
            InputStream logConfiguration = App.class.getResourceAsStream("log.properties");
            if(logConfiguration == null) {
                Terminal.get().setVisible(false);
                System.out.println("Missing log.properties file. System is closing.");
                System.out.println("Rebuild application with compile batch file.");
                System.out.println("If this doesn't help, download source files again.");
                return;
            }
            LogManager.getLogManager().readConfiguration(logConfiguration);
        } catch (SecurityException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
        } catch (FileNotFoundException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
        } catch (IOException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
        }

        logger.log(Level.INFO, "System is starting");
        InitProcess proc = new InitProcess();
        proc.setOutput(new StandardOutputService((TerminalTab) Terminal.get().getTabs().getComponent(0), false));
        proc.setError(new StandardOutputService((TerminalTab) Terminal.get().getTabs().getComponent(0), true));
        proc.setInput(new StandardInputService((TerminalTab) Terminal.get().getTabs().getComponent(0)));
        logger.log(Level.INFO, "System is started");

        Thread t = new Thread(proc);
        t.start();
        t.join();

        Terminal.get().setVisible(false);
        logger.info("System is closing");
        System.exit(1);
    }

    protected App() {

    }

}
