package os.history;

import java.util.ArrayList;
import java.util.List;

/**
 * Object for history of commands.
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 *
 */
public class History {

    private int current;
    private String login;

    private List<HistoryItem> history = new ArrayList<HistoryItem>();

    public History() {
        current = history.size();
    }

    public History(String login) {
        this.login = login;
    }

    public History(List<HistoryItem> history) {

        this.history = history;
        current = history.size();
    }

    public void addFullHistory(List<HistoryItem> history) {
        this.history = history;
        current = history.size();
    }

    public void addHistoryItem(String dir, String command) {
        
        current = history.size();
        
        if (!command.equals("")) {
            if (history.size() == 0 || (history.size() > 0 && !history.get(history.size() - 1).getCommand().equals(command))) {
                history.add(new HistoryItem(dir, command));
                current = history.size();
            }
        }
    }

    public HistoryItem getNext() {

        current++;
        if (current >= history.size()) {
            current--;
            return null;
        }

        return history.get(current);
    }

    public HistoryItem getPrevious() {

        current--;
        if (current < 0) {
            current++;
            return null;
        }

        return history.get(current);
    }

    public String getLogin() {
        return login;
    }

    public void setLogin(String login) {
        this.login = login;
    }

    protected List<HistoryItem> getHistory() {
        return history;
    }

}
