package os.io;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.util.logging.Level;
import java.util.logging.Logger;

import os.session.Session;

/**
 * File input service - read data from file.
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 * 
 */
public class FileInputService implements InputService {

    private static Logger logger = Logger.getLogger(FileInputService.class.getName());

    private BufferedReader reader;
    private FileInputStream fileReader;

    public FileInputService(File file) throws FileNotFoundException {

        try {

            fileReader = new FileInputStream(file);
            reader = new BufferedReader(new InputStreamReader(fileReader, InputService.CHARSET));

        } catch (UnsupportedEncodingException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
        }
    }

    public String readLine() {

        try {

            return reader.readLine();

        } catch (IOException e) {
            // nothing log - IOException is throwed in kill process action and is not error.
            close();
            return null;
        }
    }

    public int read() {

        try {

            return fileReader.read();

        } catch (IOException e) {
            // nothing log - IOException is throwed in kill process action and is not error.
            close();
        }

        return 0;

    }

    public int read(byte[] bytes) {

        try {

            return fileReader.read(bytes);

        } catch (IOException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            close();
        }

        return 0;

    }

    public void close() {

        try {

            reader.close();

        } catch (IOException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
        }
    }

    public int getType() {
        return InputService.FILE;
    }

    public void setSession(Session session) {
        // nothing to do - file service doesnt need session.
    }

}
