package os.io;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.logging.Level;
import java.util.logging.Logger;

import os.session.Session;

/**
 * File output service - write data into file.
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 * 
 */
public class FileOutputService implements OutputService {

    private static Logger logger = Logger.getLogger(FileOutputService.class.getName());

    private BufferedWriter writer;
    private FileOutputStream fileWriter;
    private boolean errorService;

    public FileOutputService(File file, boolean errorService, boolean append) throws IOException {
        
        fileWriter = new FileOutputStream(file, append);
        writer = new BufferedWriter(new OutputStreamWriter(fileWriter, OutputService.CHARSET));
    }

    public void write(String text) {
        
        try {
            
            writer.write(text);
            writer.flush();
            
        } catch (IOException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            close();
        }
    }

    public void write(int c) {
        
        try {
            
            writer.write(c);
            writer.flush();
            
        } catch (IOException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            close();
        }

    }

    public void write(byte[] bytes) {
        
        try {
            
            fileWriter.write(bytes);
            
        } catch (IOException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            close();
        }
    }

    public boolean isErrorService() {
        return errorService;
    }

    public void close() {
        
        try {
            
            fileWriter.flush();
            fileWriter.close();
            
        } catch (IOException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
        }
    }

    public int getType() {
        return OutputService.FILE;
    }

    public void setSession(Session session) {
        // nothing to do - file service doesnt need session.
    }

    public void shutdown() {
        close();
    }

}
