package os.io;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InterruptedIOException;
import java.io.PipedReader;
import java.util.logging.Level;
import java.util.logging.Logger;

import os.session.Session;
import os.terminal.TerminalTab;

/**
 * Standard output service - stdout.
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 * 
 */
public class StandardInputService implements InputService {

    private static Logger logger = Logger.getLogger(StandardInputService.class.getName());

    private BufferedReader reader;
    private TerminalTab tab;
    private PipedReader pipeReader;

    public StandardInputService(TerminalTab tab) {

        this.tab = tab;
        this.pipeReader = new PipedReader();
        tab.connectInput(pipeReader);
        this.reader = new BufferedReader(pipeReader);
    }

    public String readLine() {

        try {

            String line = reader.readLine();

            if (line.equalsIgnoreCase("@#$eof$#@")) {
                return null;
            } else {
                return line;
            }
        } catch (InterruptedIOException e) {
            // ignored exception - throwed when process waited on input and is interrupted.
            close();
            return null;
        } catch (IOException e) {

            logger.log(Level.SEVERE, e.getMessage(), e);
            close();
            return null;
        }
    }

    public int read() {

        try {
            return reader.read();
        } catch (IOException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
            close();
        }

        return -1;

    }

    public void close() {

    }

    public int read(byte[] bytes) {
        // stdout dont work via bytes
        throw new UnsupportedOperationException("read(byte[] bytes) cannot be used for read standard input service.");
    }

    public int getType() {
        return InputService.STANDARD;
    }

    public void setSession(Session session) {
        tab.setSession(session);
    }

}
