package os.io;

import os.session.Session;
import os.terminal.TerminalTab;

/**
 * Standard input service - stdin.
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 * 
 */
public class StandardOutputService implements OutputService {

    private TerminalTab tab;
    private boolean errorService;
    private boolean shutdown;

    public StandardOutputService(TerminalTab tab, boolean errorService) {

        this.tab = tab;
        this.errorService = errorService;
    }

    public void write(String text) {

        if (isErrorService()) {
            tab.writeError(text);
        } else {
            tab.writeOutput(text);
        }
    }

    public void write(int c) {

        char text = (char) c;
        if (isErrorService()) {
            tab.writeError(text + "");
        } else {
            tab.writeOutput(text + "");
        }
    }

    public void write(byte[] bytes) {

        String text = new String(bytes);
        if (isErrorService()) {
            tab.writeError(text);
        } else {
            tab.writeOutput(text);
        }
    }

    public boolean isErrorService() {
        return errorService;
    }

    public void close() {
        // standard input isn't closing on process end or interrupt.
    }

    public int getType() {
        return OutputService.STANDARD;
    }

    public void setSession(Session session) {
        tab.setSession(session);
    }

    public void shutdown() {

        if (shutdown) {
            return;
        } else {
            tab.writeOutput("System shutdown");
            shutdown = true;
        }
    }

}
