package os.process;

import java.util.logging.Level;
import java.util.logging.Logger;

import os.file.FileManager;
import os.history.HistoryManager;
import os.process.shell.ShellProcess;
import os.session.SessionManager;

/**
 * Init process for system.
 * 
 * Prepare managers and run first shell process.
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 * 
 */
public class InitProcess extends Process {

    private static final String COMMAND = "INIT";

    private static Logger logger = Logger.getLogger(InitProcess.class.getName());

    public InitProcess() {
        setSession(SessionManager.get().getNewSession());
    }

    @SuppressWarnings("static-access")
    public void run() {

        logger.log(Level.INFO, "init process");
        SessionManager.get();
        ProcessManager.get();
        FileManager.get();
        HistoryManager.get();

        // register init process in process manager
        ProcessManager.get().addThread(Thread.currentThread(), this);
        
        // prepare one shell process and run.
        ShellProcess shell = new ShellProcess();
        shell.setInput(getInput());
        shell.setOutput(getOutput());
        shell.setError(getError());
        shell.setSession(getSession().cloneWithUniqueId());

        ProcessManager.get().shedule(shell, this);
        shutdown();
        
        // if init isn't sleeping - its shutdown or end of system.
        ProcessManager.get().shutdown();
        SessionManager.get().shutdown();
        FileManager.get().shutdown();
        HistoryManager.get().shutdown();

        getOutput().close();
        getError().close();
        getInput().close();

        logger.log(Level.INFO, "init process ending");

        try {
            Thread.currentThread().sleep(1000);
        } catch (InterruptedException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
        }
    }

    public String getCommand() {
        return COMMAND;
    }

    public IProcess getClone() {
        return new InitProcess();
    }

    public IProcess getWeakCopy() {

        InitProcess clone = new InitProcess();
        clone.setArguments(getArgs());
        clone.setParameters(getParams());
        clone.setPid(getPid());
        clone.setParent(getParent());
        clone.setChilds(getChilds());
        return clone;
    }

}
