package os.process.shell.cd;

import java.io.File;

import os.file.FileManager;
import os.io.OutputService;
import os.process.IProcess;
import os.process.Process;

/**
 * Cd process for change actual directory.
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 *
 */
public class CdProcess extends Process {

    private static final String COMMAND = "CD";

    public CdProcess() {
        
    }

    public void run() {
        
        // do nothing if output of this process is connected over pipe to another process
        if (getOutput().getType() != OutputService.PIPE) {
        
            // if there is parameter, print error message
            if(getParams().size() != 0){
                getError().write("cd: " + getParams().get(0) + ": invalid option, use 'help cd'\n");
                Thread.currentThread().interrupt();
                return;
            }
            
            String changeDir = "..";

            if (getArgs().size() != 0) {
                changeDir = getArgs().get(0).replaceAll("\"", "");
            }

            // skip if 'cat .'
            if (!changeDir.equalsIgnoreCase(".")) {
                
                String actualDirectory = getSession().getDirectory();
                String newDirectory = changeDir;

                if (changeDir.equalsIgnoreCase("..")) {

                    // lenght -2 = avoid problems with / or \ in the end of actual dir path
                    int c = actualDirectory.length() - 2;

                    // find last file separator
                    for (; c >= 0; c--) {
                        if (actualDirectory.charAt(c) == File.separatorChar) {
                            break;
                        }
                    }

                    // if there is file separator in path remove last folder from path
                    if (c > 0) {
                        newDirectory = actualDirectory.substring(0, c);

                        if (!newDirectory.contains(File.separator)) {
                            newDirectory = newDirectory + File.separator;
                        }
                    } else {
                        if (!newDirectory.equalsIgnoreCase(File.separator)) {
                            newDirectory = actualDirectory;
                        }
                    }
                } else {
                    
                    // test if argument is absolute path to directory
                    if (!FileManager.get().isAbsoluteDir(newDirectory)) {
                        if (!actualDirectory.endsWith(File.separator)) {
                            newDirectory = actualDirectory + File.separator + changeDir;
                        } else {
                            newDirectory = actualDirectory + changeDir;
                        }
                    }
                }

                newDirectory = FileManager.get().getPathBasedOnOS(newDirectory);

                // set new path if it exists
                if (newDirectory != null && FileManager.get().isDir(newDirectory)) {
                    getSession().setDirectory(newDirectory);
                } else {
                    getError().write("cd: " + newDirectory + ": no such file or directory\n");
                }
            }
        }
    }

    public String getCommand() {
        return COMMAND;
    }

    public IProcess getClone() {
        return new CdProcess();
    }

    public IProcess getWeakCopy() {

        CdProcess clone = new CdProcess();
        clone.setArguments(getArgs());
        clone.setParameters(getParams());
        clone.setPid(getPid());
        clone.setParent(getParent());
        clone.setChilds(getChilds());
        return clone;

    }

}
