package os.process.shell.date;

import java.io.File;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;

import os.file.FileManager;
import os.process.IProcess;
import os.process.Process;

/**
 * Date process for working with date.
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 * 
 */
public class DateProcess extends Process {

    private static final String COMMAND = "DATE";

    private String DATE_FORMAT = null;
    private SimpleDateFormat format = null;
    private String formatString = null;

    public DateProcess() {

    }

    public void run() {

        Date date = new Date();
        boolean paramR = false;
        
        // go through all parameters
        for (String parameter : getParams()) {

            if (parameter.equals("-u")) {

                DATE_FORMAT = "EEE MMM dd HH:mm:ss z yyyy";
                format = new SimpleDateFormat(DATE_FORMAT);
                format.setTimeZone(TimeZone.getTimeZone("UTC"));

            } else if (parameter.equals("-R")) {

                DATE_FORMAT = "EEE, dd MMM yyyy HH:mm:ss Z";
                format = new SimpleDateFormat(DATE_FORMAT, Locale.ENGLISH);

            } else if (parameter.equals("-r")) {

                // get last modification time of file
                
                String fileName = null;
                File file = null;
                paramR = true;

                // test if argument is file, if yes, save time of last modification
                if (getArgs() != null && getArgs().size() > 0) {

                    fileName = getArgs().get(getArgs().size() - 1);
                    String path = getSession().getDirectory();

                    if (fileName != null) {

                        String filePath = null;

                        if (FileManager.get().getFile(FileManager.get().getPathBasedOnOS(fileName)) == null) {

                            if (!path.endsWith(File.separator)) {
                                filePath = FileManager.get().getPathBasedOnOS(path + File.separator + fileName);
                            } else {
                                filePath = FileManager.get().getPathBasedOnOS(path + fileName);
                            }

                        } else {
                            filePath = FileManager.get().getPathBasedOnOS(fileName);
                        }

                        if (filePath != null) {

                            file = FileManager.get().getFile(filePath);

                            if (file != null) {
                                
                                // save time of last modification
                                date = new Date(file.lastModified());
                            } else {
                                getError().write("date: " + fileName + ": No such file or directory\n");
                                close();
                                Thread.currentThread().interrupt();
                                return;
                            }

                        } else {

                            getError().write("date: " + fileName + ": No such file or directory\n");
                            close();
                            Thread.currentThread().interrupt();
                            return;
                        }
                    }
                } else {
                    getError().write("date: missing argument for option -r\n");
                    close();
                    Thread.currentThread().interrupt();
                    return;
                }
            } else {
                getError().write("date: " + parameter + ": invalid option, use 'help date'\n");
                close();
                Thread.currentThread().interrupt();
                return;
            }
        }

        // test if argument is format of date that should be printed
        if(getArgs() != null && getArgs().size() <= 1){
        	if(getArgs().size() == 1){
	        	String arguments = getArgs().get(0);
		        if (arguments.substring(0, 2).equals("+\"") && arguments.substring(arguments.length() - 1, arguments.length()).equals("\"")) {
		            formatString = arguments.substring(2, arguments.length() - 1);
		        }else if(paramR){
		        }else{
		        	 getError().write("date: " + arguments + ": invalid option, use 'help date'\n");
		             close();
		             Thread.currentThread().interrupt();
		             return;
		        }
        	}
        }else{
        	getError().write("date: invalid option, use 'help date'\n");
            close();
            Thread.currentThread().interrupt();
            return;
        }

        
        // test if there are arguments or parameters, if not print only date to output
        if (getArgs() != null && getArgs().size() > 0 || getParams() != null && getParams().size() > 0) {

            if (format != null) {
                getOutput().write(format.format(date) + "\r\n");
            } else if (formatString != null) {
            	try{
	                format = new SimpleDateFormat(formatString);
	                getOutput().write(format.format(date) + "\r\n");
	            } catch (IllegalArgumentException e) {
	                getError().write("date: " + formatString + ": invalid option, use 'help date'\n");
	                close();
	                Thread.currentThread().interrupt();
	                return;
	            }
            } else {
                getOutput().write(date + "\r\n");
            }

        } else {
            getOutput().write(date + "\r\n");
        }

        close();
    }

    public String getCommand() {
        return COMMAND;
    }

    public IProcess getClone() {
        return new DateProcess();
    }

    public IProcess getWeakCopy() {
        DateProcess clone = new DateProcess();
        clone.setArguments(getArgs());
        clone.setParameters(getParams());
        clone.setPid(getPid());
        clone.setParent(getParent());
        clone.setChilds(getChilds());
        return clone;
    }
}
