package os.process.shell.echo;

import os.process.IProcess;
import os.process.Process;

/**
 * Echo process print line of text to output.
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 * 
 */
public class EchoProcess extends Process {

    private static final String COMMAND = "ECHO";

    private boolean enableBackslash = false;

    public EchoProcess() {
    }

    public void run() {
        
        // go through parameters and set flags
        for (String parameter : getParams()) {
            if (parameter.equals("-e")) {
                enableBackslash = true;
            } else if (parameter.equals("-E")) {
                enableBackslash = false;
            } else {
                getError().write("echo: " + parameter + ": unknown parameter, use 'help echo'\n");
                close();
                Thread.currentThread().interrupt();
                return;
            }
        }

        // go through all arguments and print them to output in specific format if flags are set
        for (String argument : getArgs()) {
            if (Thread.currentThread().isInterrupted())
                break;

            argument = argument.replace("\"", "");

            if (enableBackslash) {
                argument = argument.replace("\\n", "\r\n");
                argument = argument.replace("\\t", "\t");

                if (argument.contains("\\c")) {
                    argument = argument.substring(0, argument.indexOf("\\c", 0));
                    getOutput().write(argument);
                    break;
                }
            }

            getOutput().write(argument + " ");
        }
        getOutput().write("\r\n");

        close();
    }

    public String getCommand(){
        return COMMAND;
    }

    public IProcess getClone() {
        return new EchoProcess();
    }

    public IProcess getWeakCopy() {

        EchoProcess clone = new EchoProcess();
        clone.setArguments(getArgs());
        clone.setParameters(getParams());
        clone.setPid(getPid());
        clone.setParent(getParent());
        clone.setChilds(getChilds());
        return clone;

    }

}
