package os.process.shell.help;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.logging.Level;
import java.util.logging.Logger;

import os.file.FileManager;
import os.io.FileInputService;
import os.process.IProcess;
import os.process.InitProcess;
import os.process.Process;

/**
 * Help process for get help information about command.
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 * 
 */
public class HelpProcess extends Process {

    private static Logger logger = Logger.getLogger(InitProcess.class.getName());

    private static final String COMMAND = "HELP";

    public HelpProcess() {
    }

    public void run() {

        if (getParams().size() == 0) {

            String helpDir = FileManager.get().getHelpDir();
            String helpCommandFile = null;
            File helpFile = null;
            String helpText = null;
            FileInputService input = null;

            String argument = null;

            if (getArgs().size() > 0) {
                argument = getArgs().get(0);

                if (!isProcess(argument)) {
                    getError().write("help: no help topics match '" + argument + "'\n");
                    close();
                    Thread.currentThread().interrupt();
                    return;
                }
            }

            // go through all process and print help for all process or for one process given as argument
            for (Process process : Process.runnable) {

                if (Thread.currentThread().isInterrupted())
                    break;

                if ((argument != null && process.getCommand().equalsIgnoreCase(argument)) || argument == null) {
                    helpCommandFile = FileManager.get().getPathBasedOnOS(helpDir + "/" + process.getCommand().toLowerCase() + ".help");
                    helpFile = FileManager.get().getFile(helpCommandFile);

                    if (helpFile != null) {

                        try {
                            input = new FileInputService(helpFile);

                            // read first line with brief info from help file
                            helpText = input.readLine();
                            if (helpText == null) {
                                getError().write("Help file '" + process.getCommand().toLowerCase() + ".help' does not contain help text.\n");
                                continue;
                            }

                            if (argument == null) {
                                
                                // print only first line with brief help
                                getOutput().write(" " + helpText + "\r\n");
                            } else {
                                
                                // print remaining lines from help file
                                while ((helpText = input.readLine()) != null) {
                                    getOutput().write(helpText + "\r\n");
                                }
                            }

                        } catch (FileNotFoundException e) {
                            logger.log(Level.WARNING, e.getMessage(), e);
                            e.printStackTrace();
                        } finally {
                            if (input != null) {
                                input.close();
                            }
                        }
                    } else {
                        getError().write(process.getCommand() + ": help file does not exist\n");
                    }
                }
            }
        } else {
            getError().write("help: " + getParams().get(0) + ": invalid option, use 'help help'\n");
        }

        close();
    }

    public String getCommand() {
        return COMMAND;
    }

    public IProcess getClone() {
        return new HelpProcess();
    }

    public IProcess getWeakCopy() {

        HelpProcess clone = new HelpProcess();
        clone.setArguments(getArgs());
        clone.setParameters(getParams());
        clone.setPid(getPid());
        clone.setParent(getParent());
        clone.setChilds(getChilds());
        return clone;

    }
}
