package os.process.shell.kill;

import os.io.OutputService;
import os.process.IProcess;
import os.process.Process;
import os.process.ProcessManager;

/**
 * Kill process - signal for terminate process with pid.
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 * 
 */
public class KillProcess extends Process {

    private static final String COMMAND = "KILL";

    public void run() {

        if (getOutput().getType() != OutputService.PIPE) {

            if (getParams().size() != 0) {
                getError().write("kill: " + getParams().get(0) + ": invalid option, use 'help kill'\n");
                close();
                Thread.currentThread().interrupt();
                return;
            }

            if (getArgs() != null && getArgs().size() > 0) {

                if (getArgs().size() == 1) {
                    String argument = getArgs().get(0);

                    try {

                        long pid = Long.valueOf(argument);
                        ProcessManager.get().kill(pid);
                        close();
                        Thread.currentThread().interrupt();
                        return;

                    } catch (NumberFormatException e) {

                        getError().write("kill: " + argument + ": not valid PID number, use 'help kill'\n");
                        close();
                        Thread.currentThread().interrupt();
                        return;
                    }
                } else {

                    getError().write("kill: too many arguments, use 'help kill'\n");
                    close();
                    Thread.currentThread().interrupt();
                    return;
                }

            } else {
                getError().write("kill: missing argument, use 'help kill'\n");
                close();
                Thread.currentThread().interrupt();
                return;
            }
        }
    }

    public String getCommand() {
        return COMMAND;
    }
    
    public IProcess getClone() {
        return new KillProcess();
    }

    public IProcess getWeakCopy() {

        KillProcess clone = new KillProcess();
        clone.setArguments(getArgs());
        clone.setParameters(getParams());
        clone.setPid(getPid());
        clone.setParent(getParent());
        clone.setChilds(getChilds());
        return clone;

    }

}
