package os.process.shell.login;

import os.io.OutputService;
import os.process.IProcess;
import os.process.Process;
import os.session.SessionManager;

/**
 * Login process for login session.
 * 
 *  @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 * 
 */
public class LoginProcess extends Process {

    private static final String COMMAND = "LOGIN";

    public LoginProcess() {

    }

    public void run() {

        // login can't use in pipes
        if (getOutput().getType() != OutputService.PIPE) {

            if (getParams() != null && getParams().size() > 0 || getArgs() != null && getArgs().size() > 0) {

                getError().write("login: invalid option, use 'help login'\n");
                close();
                Thread.currentThread().interrupt();
                return;
            }

            getOutput().write("login name:\n");
            String name = getInput().readLine();

            if (name != null && !name.isEmpty()) {

                SessionManager.get().loginSession(getSession(), name);
                getOutput().write(name + "\n");
            }

            close();
        }
    }

    public String getCommand() {
        return COMMAND;
    }

    public IProcess getClone() {
        return new LoginProcess();
    }

    public IProcess getWeakCopy() {

        LoginProcess clone = new LoginProcess();
        clone.setArguments(getArgs());
        clone.setParameters(getParams());
        clone.setPid(getPid());
        clone.setParent(getParent());
        clone.setChilds(getChilds());
        return clone;
    }

}
