package os.process.shell.ps;

import java.util.Arrays;
import java.util.Map;

import os.process.IProcess;
import os.process.Process;
import os.process.ProcessManager;
/**
 * 
 * PS process for show actual processes in process's table
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 *
 */
public class PSProcess extends Process {

    private static final String LINE_END = "\r\n";
    private static final String outputLineHead = " | %-4s | %-4s | %-8s | %-10s | %-20s and  %-20s";
    private static final String outputLine = " | %-4d | %-4d | %-8s | %-10s | %-20s  %-20s";
    private static final String COMMAND = "PS";

    public PSProcess() {

    }

    public void run() {
        
        if(getParams() != null && getParams().size() > 0 || getArgs() != null && getArgs().size() > 0 ){
            getError().write("ps: invalid option, use 'help ps'\n");
            Thread.currentThread().interrupt();
            return;
        }
        
        Map<Long, IProcess> processMap = ProcessManager.get().getRunnableMap();
        Map<Long, String> statusMap = ProcessManager.get().getThreadStatusMap();

        String head = String.format(outputLineHead, "PID", "PPID", "COMMAND", "STATUS", "ARGS", "PARAMETERS" );
        String head2 = String.format(outputLineHead, "---", "----", "--------", "----------", "--------------------", "--------------------" );
        getOutput().write(head + LINE_END);
        getOutput().write(head2 + LINE_END);
        
        // write information about processes's in process table
        for (Long id : processMap.keySet()) {
            
            if(Thread.currentThread().isInterrupted())
                break;
            
            IProcess proc = processMap.get(id);
            Long pid = proc.getPid();
            Long parent = proc.getParent();
            String command = proc.getCommand();
            String status = statusMap.get(id);
            String args = Arrays.toString(proc.getArgs().toArray());
            String params = Arrays.toString(proc.getParams().toArray());
            String string = String.format(outputLine, pid, parent, command, status, args, params);
            getOutput().write(string +LINE_END);
        }
        Thread.currentThread().interrupt();
        close();
    }

    public String getCommand(){
        return COMMAND;
    }
    
    public IProcess getClone() {
        return new PSProcess();
    }

    public IProcess getWeakCopy() {

        PSProcess clone = new PSProcess();
        clone.setArguments(getArgs());
        clone.setParameters(getParams());
        clone.setPid(getPid());
        clone.setParent(getParent());
        clone.setChilds(getChilds());
        return clone;
    }

}
