package os.terminal;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JFrame;
import javax.swing.JTabbedPane;

import os.process.ProcessManager;

/**
 * Terminal window class.
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 * 
 */
public class Terminal extends JFrame {

    private static final long serialVersionUID = 19230778208320025L;

    private static Terminal terminal;
    private JTabbedPane tabs;

    public Terminal() {

        setTitle("OSMRR Moulis (A13N0118P), Rinkes (A13N0124P), Rendl (A13N0123P) KIV/OS 2013/2014");
        Dimension windowSize = new Dimension(1000, 600);
        setMinimumSize(windowSize);
        setLocationRelativeTo(null);

        // do nothing bc system is closed by shutdown command
        setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);

        addWindowListener(new WindowAdapter() {

            @Override
            public void windowClosing(WindowEvent e) {
                super.windowClosing(e);
                ProcessManager.get().shutdown();
            }

        });

        // tabs for paralel system.
        tabs = new JTabbedPane();
        tabs.addTab("system tab 1", new TerminalTab());
        tabs.setFocusable(false);

        getContentPane().add(tabs, BorderLayout.CENTER);

        pack();
        setVisible(true);
    }

    public JTabbedPane getTabs() {
        return tabs;
    }

    public static Terminal get() {

        if (terminal == null)
            init();

        return terminal;
    }

    public static void init() {
        terminal = new Terminal();
    }

}
