package os.terminal;

import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.io.IOException;
import java.io.PipedWriter;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.swing.JTextArea;

import os.history.HistoryItem;
import os.process.ProcessManager;
import os.session.Session;

/**
 * Terminal window key listener class.
 * 
 * @author Jakub Rinkes, Jan Moulis, Kamil Rendl
 * 
 */
public class TerminalKeyTabListener extends KeyAdapter {

    private static final String EOF_INPUT = "@#$eof$#@\n";
    private static final String LINE_END = "\n";
    private static final String LINE_END_REGEX = "[\n\r]";

    private static Logger logger = Logger.getLogger(TerminalKeyTabListener.class.getName());

    private JTextArea outputArea;
    private JTextArea inputArea;
    private PipedWriter writer;
    private Session session;

    public TerminalKeyTabListener(JTextArea area, JTextArea area2) {

        this.outputArea = area;
        this.inputArea = area2;
        this.writer = new PipedWriter();

    }

    @Override
    public void keyReleased(KeyEvent event) {
        try {

            // ENTER
            if (event.getKeyCode() == KeyEvent.VK_ENTER) {

                String input = inputArea.getText();
                input = input.replaceAll(LINE_END_REGEX, "");
                input = input + LINE_END;
                writer.write(input);
                writer.flush();
                inputArea.setText("");
                inputArea.setCaretPosition(0);
                inputArea.updateUI();
                outputArea.updateUI();
            }

        } catch (IOException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
        }
    }

    @Override
    public void keyPressed(KeyEvent event) {

        try {

            // UP in history
            if (event.getKeyCode() == KeyEvent.VK_UP) {

                HistoryItem item = session.getHistory().getPrevious();
                if (item != null) {
                    inputArea.setText(item.getCommand());
                }

                // DOWN in history
            } else if (event.getKeyCode() == KeyEvent.VK_DOWN) {

                HistoryItem item = session.getHistory().getNext();
                if (item != null) {
                    inputArea.setText(item.getCommand());
                }

                // CTRL + D
            } else if (event.getKeyCode() == KeyEvent.VK_D && event.isControlDown()) {

                inputArea.setText("");
                inputArea.setCaretPosition(0);
                inputArea.updateUI();
                writer.write(EOF_INPUT);
                writer.flush();

                // CTRL + C
            } else if (event.getKeyCode() == KeyEvent.VK_C && event.isControlDown()) {

                writer.write(LINE_END);
                writer.flush();
                ProcessManager.get().signalInterupt(session);

            }
        } catch (IOException e) {
            logger.log(Level.SEVERE, e.getMessage(), e);
        }
    }

    public PipedWriter getWriter() {
        return writer;
    }

    public void setSession(Session session) {
        this.session = session;
    }
}
